package main

import (
	"flag"
	"fmt"
	"github.com/nacos-group/nacos-sdk-go/v2/common/constant"
	"github.com/zeromicro/zero-contrib/zrpc/registry/nacos"
	//"github.com/nacos-group/nacos-sdk-go/v2/common/constant"
	"github.com/zeromicro/go-zero/core/conf"
	"github.com/zeromicro/go-zero/core/service"
	"github.com/zeromicro/go-zero/zrpc"
	//"github.com/zeromicro/zero-contrib/zrpc/registry/nacos"
	"google.golang.org/grpc"
	"google.golang.org/grpc/reflection"
	"trasfer_middleware/cmd/rpc/internal/config"
	"trasfer_middleware/cmd/rpc/internal/server"
	"trasfer_middleware/cmd/rpc/internal/svc"
	"trasfer_middleware/cmd/rpc/pb/transfer"
	"trasfer_middleware/until"
)

var configFile = flag.String("f", fmt.Sprintf("%s%s", "../../config/", until.GetConfig()), "the config file")

func main() {
	flag.Parse()
	var c config.Config
	conf.MustLoad(*configFile, &c)
	ctx := svc.NewServiceContext(c)

	s := zrpc.MustNewServer(c.RpcServerConf, func(grpcServer *grpc.Server) {
		transfer.RegisterTransferServer(grpcServer, server.NewTransferServer(ctx))
		if c.Mode == service.DevMode || c.Mode == service.TestMode {
			reflection.Register(grpcServer)
		}
	})

	registerNacos(&c)
	//until_nacos.NewRegistrarxxx(
	//	c.Nacos.Hosts,
	//	c.Nacos.Port,
	//	v1c.WithNamespaceId(c.Nacos.NameSpace),
	//	v1c.WithLogDir("./log/base"),
	//)

	defer s.Stop()

	fmt.Printf("Starting rpc server at %s...\n", c.ListenOn)
	s.Start()
}

func registerNacos(c *config.Config) {
	sc := []constant.ServerConfig{}
	sc = append(sc, *constant.NewServerConfig(c.Nacos.Hosts, c.Nacos.Port))

	cc := &constant.ClientConfig{
		NamespaceId:         c.Nacos.NameSpace,
		TimeoutMs:           c.Nacos.TimeOut,
		NotLoadCacheAtStart: true,
		//Username:            c.Nacos.Username,
		//Password:            c.Nacos.Password,
		LogDir:   "/tmp/nacos/log",
		CacheDir: "/tmp/nacos/cache",
		LogLevel: "debug",
	}
	//splitSlice := strings.Split(c.ListenOn, ":")
	//ip, _ := common.GetLocalIP()
	opts := nacos.NewNacosConfig(c.Nacos.ServiceName, c.ListenOn, sc, cc)

	err := nacos.RegisterService(opts)
	if err != nil {
		panic(err)
	}
	fmt.Printf("rpc 连接成功")
}
